/*
 *   ChordVerifier - Verifies that chord lengths input are reasonable.
 *
 *   Copyright (C) 1998-2016, by Joseph A. Huwaldt.
 *   All rights reserved.
 *   
 *   This library is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU Lesser General Public
 *   License as published by the Free Software Foundation; either
 *   version 2.1 of the License, or (at your option) any later version.
 *   
 *   This library is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *   Library General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *  Or visit:  http://www.gnu.org/licenses/lgpl.html
 */
package jahuwaldt.js.pmethods.winggeom;

import jahuwaldt.js.ParamTools.*;
import jahuwaldt.js.param.Parameter;
import java.awt.Component;
import javax.swing.*;

/**
 * Verifies that the Root Chord Length the user entered is greater than zero.
 * 
 * <p> Modified by: Joseph A. Huwaldt </p>
 * 
 * @author Joseph A. Huwaldt, Date: October 1, 1998
 * @version March 26, 2016
 */
@SuppressWarnings("serial")
public class ChordVerifier implements ParamVerifier {

    /**
     * Check to see if the input value is valid for this parameter.
     *
     * @param root  The root component containing the parameter input text field for the
     *              parameter being verified.
     * @param value The value of the parameter as input by the user.
     * @return If "value" is valid, it should be output. If "value" is invalid or out of
     *         range, a valid value is output or Float.NaN if nothing else. If ParamInput
     *         (which calls this routine) receives a value of Float.NaN, it will clear the
     *         parameter.
     */
    @Override
    public Parameter check(Component root, Parameter value) {
        Parameter outValue = value;

        if (outValue.getValue() < 0) {
            outValue = Parameter.valueOf(1, value.getUnit());
            JOptionPane.showMessageDialog(root, "Chord length's must be non-zero positive numbers!",
                    "Out of Range",
                    JOptionPane.ERROR_MESSAGE);
        }

        return outValue;
    }

}
