/*
*   yMACfn_etaMAC_b - Method for calculating yMAC as a function of etaMAC and b.
*
*   Copyright (C) 1998-2009 by Joseph A. Huwaldt
*   All rights reserved.
*   
*   This library is free software; you can redistribute it and/or
*   modify it under the terms of the GNU Lesser General Public
*   License as published by the Free Software Foundation; either
*   version 2.1 of the License, or (at your option) any later version.
*   
*   This library is distributed in the hope that it will be useful,
*   but WITHOUT ANY WARRANTY; without even the implied warranty of
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
*   Library General Public License for more details.
*
*  You should have received a copy of the GNU Lesser General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*  Or visit:  http://www.gnu.org/licenses/lgpl.html
**/
package jahuwaldt.js.pmethods.winggeom;


import javax.measure.quantity.Length;
import javax.measure.unit.SI;

import jahuwaldt.js.param.Parameter;
import jahuwaldt.js.ParamTools.*;


/**
*  <p>  Calculates spanwise location of MAC (Cbar) based on
*       fractinal spanwise location of MAC and wing span.
*  </p>
*
*  <p>  Modified by:  Joseph A. Huwaldt   </p>
*
*  @author   Joseph A. Huwaldt   Date:  February 7, 1999
*  @version  April 26, 2009
**/
public class yMACfn_etaMAC_b extends AbstractParamMethod<Length> {

	/**
	*  Constructor for this method.
	*
	*  @param  etaMAC  Label for the "fractional spanwise location of MAC" parameter.
	*  @param  b  Label for the "span" parameter.
	**/
	public yMACfn_etaMAC_b( String etaMAC, String b ) {
		_inputLabels = new String [ 2 ];
		_inputLabels[0] = etaMAC;
		_inputLabels[1] = b;
	}

	/**
	*  Calculates spanwise location of MAC (Cbar) based
	*  on fractinal spanwise location of MAC and wing span.
	*  Method:  yMAC = etaMAC*b/2
	*
	*  @param  inputs  Array of input parameters.
	*                  [0=fractional spanwise locatin of MAC (etaMAC),
	*                   1=wing span (b)].
	*  @return  Spanwise location of the MAC (Cbar) in base units of length.
	**/
	public Parameter<Length> calc( Parameter[] inputs ) {
		Parameter etaMAC = inputs[0];
		Parameter b = inputs[1];
		Parameter yMAC = etaMAC.times(b).divide(2);		//	yMAC = etaMAC * b * 0.5;
		return yMAC.asType(Length.class);
	}


}


